package com.caimei365.manager.dao;

import com.caimei365.manager.entity.wechat.WechatMenu;
import com.caimei365.manager.entity.wechat.WechatReply;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2022/1/5
 */
@Mapper
public interface WeChatDao {
    /**
     * 获取微信公众号菜单列表
     * @param parentId 父级ID
     * @param wxType   微信公众号ID
     */
    List<WechatMenu> getWechatMenuList(Integer parentId, String wxType);
    /**
     * 根据ID获取微信公众号菜单
     */
    WechatMenu getWechatMenu(Integer id);
    /**
     * 根据ID更新微信公众号菜单
     */
    void updateWechatMenu(WechatMenu menu);
    /**
     * 添加微信公众号菜单
     */
    void insertWechatMenu(WechatMenu menu);
    /**
     * 根据ID删除微信公众号菜单
     */
    void deleteWechatMenu(Integer id);
    /**
     * 根据父级Id统计同级别菜单数量
     * @param parentId 父级ID
     */
    Integer countChildByParentId(Integer parentId);

    /**
     * 获取微信公众号菜单列表
     * @param wxType 公众号Id
     * @param title 回复素材标题
     * @param responseType   事件类型
     * @param msgType   回复类型
     */
    List<WechatReply> getReplyList(String wxType, String title, String responseType, String msgType);
    /**
     * 根据ID获取回复配置
     */
    WechatReply getWechatReply(Integer id);
    /**
     * 根据ID更新回复配置
     */
    void updateWechatReply(WechatReply dbReply);
    /**
     * 添加回复配置
     */
    void insertWechatReply(WechatReply reply);
    /**
     * 根据ID删除微信公众号回复配置
     */
    void deleteWechatReply(Integer id);
}
